@@ -95,7 +95,7 @@ MENUS = {
                     "validators": [
                         (
                             "aleksis.core.util.predicates.permission_validator",
-                            "paweljong.manage_registrations",
+                            "paweljong.view_registrations_rule",
                         )
                     ],
                 },
