@@ -274,6 +274,9 @@ class EventRegistration(ExtensibleModel):
     def get_person(self):
         return self.person
 
+    def get_billing_email_recipients(self):
+        return [self.person.email] + list(self.person.guardians.values_list("email", flat=True))
+
     def get_invoice(self):
         # FIXME Maybe do not hard-code this
         client, __ = Client.objects.get_or_create(name="Teckids e.V.")
