@@ -142,7 +142,7 @@ def registrations(request: HttpRequest) -> HttpResponse:
 
     # Get all registrations
     registrations = queryset_rules_filter(
-        request.user, EventRegistration.objects.all(), "paweljong.manage_registrations_rule"
+        request.user, EventRegistration.objects.all(), "paweljong.view_registration_rule"
     )
 
     # Get filter
